@@ -17,13 +17,12 @@ import re
 import warnings
 from pathlib import Path
 from textwrap import dedent, indent
-from typing import Optional
 
 from ._compat import cache
 
 
 @cache
-def convert(docstring: str, docformat: str, source_file: Optional[Path]) -> str:
+def convert(docstring: str, docformat: str, source_file: Path | None) -> str:
     """
     Convert `docstring` from `docformat` to Markdown.
     """
@@ -151,11 +150,11 @@ def numpy(docstring: str) -> str:
             "Warns",
             "Attributes",
         ):
-            contents += f"###### {heading}\n" f"{_numpy_parameters(content)}"
+            contents += f"###### {heading}\n{_numpy_parameters(content)}"
         elif heading == "See Also":
-            contents += f"###### {heading}\n" f"{_numpy_seealso(content)}"
+            contents += f"###### {heading}\n{_numpy_seealso(content)}"
         else:
-            contents += f"###### {heading}\n" f"{dedent(content)}"
+            contents += f"###### {heading}\n{dedent(content)}"
         contents += tail
     return contents
 
@@ -201,7 +200,7 @@ def _numpy_parameters(content: str) -> str:
     return f"{contents}\n"
 
 
-def rst(contents: str, source_file: Optional[Path]) -> str:
+def rst(contents: str, source_file: Path | None) -> str:
     """
     Convert reStructuredText elements to Markdown.
     We support the most common elements, but we do not aim to mirror the full complexity of the spec here.
@@ -220,6 +219,8 @@ def rst(contents: str, source_file: Optional[Path]) -> str:
 
     contents = _rst_footnotes(contents)
 
+    contents = _rst_fields(contents)
+
     return contents
 
 
@@ -304,7 +305,7 @@ def _rst_links(contents: str) -> str:
     return contents
 
 
-def _rst_admonitions(contents: str, source_file: Optional[Path]) -> str:
+def _rst_admonitions(contents: str, source_file: Path | None) -> str:
     """
     Convert reStructuredText admonitions - a bit tricky because they may already be indented themselves.
     <https://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html>
@@ -320,17 +321,24 @@ def _rst_admonitions(contents: str, source_file: Optional[Path]) -> str:
             loc = source_file or Path(".")
             try:
                 included = (loc.parent / val).read_text("utf8", "replace")
-            except IOError as e:
-                warnings.warn(f"Cannot include {val!r}: {e}", RuntimeWarning)
+            except OSError as e:
+                warnings.warn(f"Cannot include {val!r}: {e}")
                 included = "\n"
             included = _rst_admonitions(included, loc.parent / val)
             return indent(included, ind)
         if type == "math":
             return f"{ind}$${val}{contents}$$\n"
-        if type == "note":
-            text = val or "Note"
-        elif type == "warning":
-            text = val or "Warning"
+        if type in ("note", "warning", "danger"):
+            if val:
+                heading = f"{ind}###### {val}\n"
+            else:
+                heading = ""
+            return (
+                f'{ind}<div class="pdoc-alert pdoc-alert-{type}" markdown="1">\n'
+                f"{heading}"
+                f"{indent(contents, ind)}\n"
+                f"{ind}</div>\n"
+            )
         elif type == "versionadded":
             text = f"New in version {val}"
         elif type == "versionchanged":
@@ -347,9 +355,7 @@ def _rst_admonitions(contents: str, source_file: Optional[Path]) -> str:
 
         return text
 
-    admonition = (
-        "note|warning|versionadded|versionchanged|deprecated|seealso|math|include"
-    )
+    admonition = "note|warning|danger|versionadded|versionchanged|deprecated|seealso|math|include"
     return re.sub(
         rf"""
             ^(?P<indent>[ ]*)\.\.[ ]+(?P<type>{admonition})::(?P<val>.*)
@@ -363,3 +369,60 @@ def _rst_admonitions(contents: str, source_file: Optional[Path]) -> str:
         contents,
         flags=re.MULTILINE | re.VERBOSE,
     )
+
+
+def _rst_fields(contents: str) -> str:
+    """
+    Convert reStructuredText fields to Markdown.
+    <https://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html#rst-field-lists>
+    """
+
+    _has_parameter_section = False
+    _has_raises_section = False
+
+    def _rst_field(m: re.Match[str]) -> str:
+        type = m["type"]
+        body = m["body"]
+
+        if m["name"]:
+            name = f"**{m['name'].strip()}**: "
+        else:
+            name = ""
+
+        if type == "param":
+            nonlocal _has_parameter_section
+            text = f" - {name}{body}"
+            if not _has_parameter_section:
+                _has_parameter_section = True
+                text = "\n###### Parameters\n" + text
+            return text
+        elif type == "type":
+            return ""  # we expect users to use modern type annotations.
+        elif type == "return":
+            body = indent(body, "> ", lambda line: True)
+            return f"\n###### Returns\n{body}"
+        elif type == "rtype":
+            return ""  # we expect users to use modern type annotations.
+        elif type == "raises":
+            nonlocal _has_raises_section
+            text = f" - {name}{body}"
+            if not _has_raises_section:
+                _has_raises_section = True
+                text = "\n###### Raises\n" + text
+            return text
+        else:  # pragma: no cover
+            raise AssertionError("unreachable")
+
+    field = "param|type|return|rtype|raises"
+    return re.sub(
+        rf"""
+            ^:(?P<type>{field})(?:[ ]+(?P<name>.+))?:
+            (?P<body>.*(
+                (?:\n[ ]*)*  # maybe some empty lines followed by
+                [ ]+.+       # lines with indentation
+            )*(?:\n|$))
+        """,
+        _rst_field,
+        contents,
+        flags=re.MULTILINE | re.VERBOSE,
+    )
